@@ -471,7 +471,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/validity.html">单元格内容的有效性</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="05"><label for="05">图表</label><ul>\
+    <ul><li><input type="checkbox" id="05"><label for="05">图表与图示</label><ul>\
     <li><input type="checkbox" id="0501"><label for="0501">常规信息</label><ul>\
     <li><a target="_top" href="zh-CN/text/schart/main0000.html">LibreOffice 中的图表</a></li>\
     <li><a target="_top" href="zh-CN/text/schart/main0503.html">LibreOffice 图表功能</a></li>\
@@ -595,7 +595,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图库复制图形</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_table.html">复制电子表格区域至文本文档</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="1012"><label for="1012">图表</label><ul>\
+    <li><input type="checkbox" id="1012"><label for="1012">图表与图示</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/chart_insert.html">插入图表</a></li>\
     <li><a target="_top" href="zh-CN/text/schart/main0000.html">LibreOffice 中的图表</a></li>\
 		</ul></li>\
@@ -713,7 +713,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/main0209.html">标尺</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0210.html">绘图栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0211.html">大纲工具栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/simpress/main0212.html">幻灯片浏览栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/simpress/main0212.html">「幻灯片浏览」栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0213.html">选项栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0214.html">图像栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
@@ -779,7 +779,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/guide/animated_gif_create.html">创建动画 GIF 图像</a></li>\
          </ul></li>\
     <li><input type="checkbox" id="0407"><label for="0407">对象、图形和位图</label><ul>\
-    <li><a target="_top" href="zh-CN/text/sdraw/guide/combine_etc.html">组合对象和构造形状</a></li>\
+    <li><a target="_top" href="zh-CN/text/sdraw/guide/combine_etc.html">结合对象与构造形状</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/draw_sector.html">绘制扇形和圆缺</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/duplicate_object.html">复制对象</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/rotate_object.html">旋转对象</a></li>\
@@ -966,7 +966,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉与页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_chapter.html">在页眉或页脚中插入章节名称和编号</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/shortcut_writing.html">输入时应用文本格式</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/reset_format.html">重设字体属性</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/reset_format.html">重置字体属性</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/stylist_fillformat.html">在填充格式模式中应用样式</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/wrap.html">围绕对象的文字环绕</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/text_centervert.html">利用框架使文字在页面上居中</a></li>\
